package cn.com.infosec.x509;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREnumerated;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.x509.AccessDescription;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.AuthorityInformationAccess;
import cn.com.infosec.asn1.x509.AuthorityKeyIdentifier;
import cn.com.infosec.asn1.x509.BasicConstraints;
import cn.com.infosec.asn1.x509.CRLDistPoint;
import cn.com.infosec.asn1.x509.DistributionPoint;
import cn.com.infosec.asn1.x509.DistributionPointName;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.GeneralNames;
import cn.com.infosec.asn1.x509.IssuingDistributionPoint;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.asn1.x509.qualified.ETSIQCObjectIdentifiers;
import cn.com.infosec.asn1.x509.qualified.MonetaryValue;
import cn.com.infosec.asn1.x509.qualified.QCStatement;
import cn.com.infosec.asn1.x509.qualified.RFC3739QCObjectIdentifiers;
import cn.com.infosec.i18n.ErrorBundle;
import cn.com.infosec.i18n.LocaleString;
import cn.com.infosec.i18n.filter.TrustedInput;
import cn.com.infosec.i18n.filter.UntrustedInput;
import cn.com.infosec.i18n.filter.UntrustedUrlInput;
import cn.com.infosec.jce.provider.AnnotatedException;
import cn.com.infosec.jce.provider.CertPathValidatorUtilities;
import cn.com.infosec.x509.extension.X509ExtensionUtil;
import java.io.IOException;
import java.math.BigInteger;
import java.net.HttpURLConnection;
import java.net.InetAddress;
import java.net.URL;
import java.security.GeneralSecurityException;
import java.security.PublicKey;
import java.security.SignatureException;
import java.security.cert.CertPath;
import java.security.cert.CertPathValidatorException;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateFactory;
import java.security.cert.CertificateNotYetValidException;
import java.security.cert.PKIXParameters;
import java.security.cert.PolicyNode;
import java.security.cert.TrustAnchor;
import java.security.cert.X509CRL;
import java.security.cert.X509CRLEntry;
import java.security.cert.X509CertSelector;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.Vector;
import javax.security.auth.x500.X500Principal;

public class PKIXCertPathReviewer extends CertPathValidatorUtilities {
   private static final String QC_STATEMENT;
   private static final String CRL_DIST_POINTS;
   private static final String AUTH_INFO_ACCESS;
   private static final String RESOURCE_NAME = "cn.com.infosec.x509.CertPathReviewerMessages";
   protected CertPath certPath;
   protected PKIXParameters pkixParams;
   protected Date validDate;
   protected List certs;
   protected int n;
   protected List[] notifications;
   protected List[] errors;
   protected TrustAnchor trustAnchor;
   protected PublicKey subjectPublicKey;
   protected PolicyNode policyTree;
   private boolean initialized;

   static {
      QC_STATEMENT = X509Extensions.QCStatements.getId();
      CRL_DIST_POINTS = X509Extensions.CRLDistributionPoints.getId();
      AUTH_INFO_ACCESS = X509Extensions.AuthorityInfoAccess.getId();
   }

   public PKIXCertPathReviewer(CertPath certPath, PKIXParameters params) {
      this.init(certPath, params);
   }

   public PKIXCertPathReviewer() {
   }

   private void checkNameConstraints() {
      // $FF: Couldn't be decompiled
   }

   private void checkPathLength() {
      Object var1 = this.n;
      int var2 = 0;

      Object var11;
      for(int var3 = this.certs.size() - 1; var3 > 0; var1 = var11) {
         X509Certificate var4;
         if (!CertPathValidatorUtilities.isSelfIssued(var4 = (X509Certificate)this.certs.get(var3))) {
            if (var1 <= 0) {
               ErrorBundle var5;
               var5 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.pathLenghtExtended");
               this.addError(var5);
            }

            --var1;
            ++var2;
         }

         label31: {
            BasicConstraints var10000;
            try {
               var10000 = BasicConstraints.getInstance(CertPathValidatorUtilities.getExtensionValue(var4, CertPathValidatorUtilities.BASIC_CONSTRAINTS));
            } catch (AnnotatedException var6) {
               ErrorBundle var10;
               var10 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.processLengthConstError");
               this.addError(var10, var3);
               var11 = null;
               break label31;
            }

            var11 = var10000;
         }

         if (var11 == null || (var11 = ((BasicConstraints)var11).getPathLenConstraint()) == null || (var11 = ((BigInteger)var11).intValue()) >= var1) {
            var11 = var1;
         }

         --var3;
      }

      ErrorBundle var7;
      ErrorBundle var10001 = var7 = new ErrorBundle;
      Object[] var8;
      Object[] var10002 = var8 = new Object[1];
      Integer var9;
      var9 = new Integer.<init>(var2);
      var10002[0] = var9;
      var10001.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.totalPathLength", var8);
      this.addNotification(var7);
   }

   private void checkSignatures() {
      PKIXCertPathReviewer var10000 = this;
      PKIXCertPathReviewer var10001 = this;
      TrustAnchor var1 = null;
      X500Principal var2 = null;
      Object[] var3;
      Object[] var10005 = var3 = new Object[2];
      TrustedInput var4;
      var4 = new TrustedInput.<init>(this.validDate);
      var10005[0] = var4;
      var4 = new TrustedInput.<init>(new Date());
      var10005[1] = var4;
      this.addNotification(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.certPathValidDate", var3));

      Object[] var10006;
      Object[] var10007;
      X509Certificate var68;
      CertPathReviewerException var99;
      boolean var100;
      ErrorBundle var105;
      ErrorBundle var108;
      boolean var110;
      X509Certificate var114;
      PublicKey var116;
      label505: {
         label509: {
            int var10002;
            List var102;
            try {
               var102 = var10001.certs;
               var10002 = var102.size();
            } catch (CertPathReviewerException var65) {
               var99 = var65;
               var100 = false;
               break label509;
            }

            --var10002;

            X509Certificate var104;
            try {
               var104 = (X509Certificate)var102.get(var10002);
            } catch (CertPathReviewerException var64) {
               var99 = var64;
               var100 = false;
               break label509;
            }

            var68 = var104;

            Collection var101;
            try {
               var101 = var10000.getTrustAnchors(var104, this.pkixParams.getTrustAnchors());
            } catch (CertPathReviewerException var63) {
               var99 = var63;
               var100 = false;
               break label509;
            }

            Collection var70 = var101;

            int var103;
            try {
               var103 = var101.size();
            } catch (CertPathReviewerException var62) {
               var99 = var62;
               var100 = false;
               break label509;
            }

            String var10003;
            String var10004;
            byte var10008;
            byte var115;
            if (var103 > 1) {
               label510: {
                  try {
                     var10000 = this;
                     var108 = new ErrorBundle;
                  } catch (CertPathReviewerException var50) {
                     var99 = var50;
                     var100 = false;
                     break label510;
                  }

                  var105 = var108;
                  var10003 = "cn.com.infosec.x509.CertPathReviewerMessages";
                  var10004 = "CertPathReviewer.conflictingTrustAnchors";

                  try {
                     var10005 = new Object[2];
                  } catch (CertPathReviewerException var49) {
                     var99 = var49;
                     var100 = false;
                     break label510;
                  }

                  var10006 = var10005;
                  var10007 = var10005;
                  var10008 = 0;

                  try {
                     var10007[var10008] = new Integer(var70.size());
                  } catch (CertPathReviewerException var48) {
                     var99 = var48;
                     var100 = false;
                     break label510;
                  }

                  var115 = 1;

                  try {
                     var10006[var115] = new UntrustedInput(var68.getIssuerX500Principal());
                     var105.<init>(var10003, var10004, var10005);
                     var10000.addError(var108);
                     break label505;
                  } catch (CertPathReviewerException var47) {
                     var99 = var47;
                     var100 = false;
                  }
               }
            } else {
               label488: {
                  try {
                     var110 = var70.isEmpty();
                  } catch (CertPathReviewerException var61) {
                     var99 = var61;
                     var100 = false;
                     break label488;
                  }

                  if (var110) {
                     label511: {
                        try {
                           var10000 = this;
                           var108 = new ErrorBundle;
                        } catch (CertPathReviewerException var54) {
                           var99 = var54;
                           var100 = false;
                           break label511;
                        }

                        var105 = var108;
                        var10003 = "cn.com.infosec.x509.CertPathReviewerMessages";
                        var10004 = "CertPathReviewer.noTrustAnchorFound";

                        try {
                           var10005 = new Object[2];
                        } catch (CertPathReviewerException var53) {
                           var99 = var53;
                           var100 = false;
                           break label511;
                        }

                        var10006 = var10005;
                        var10007 = var10005;
                        var10008 = 0;

                        try {
                           var10007[var10008] = new UntrustedInput(var68.getIssuerX500Principal());
                        } catch (CertPathReviewerException var52) {
                           var99 = var52;
                           var100 = false;
                           break label511;
                        }

                        var115 = 1;

                        try {
                           var10006[var115] = new Integer(this.pkixParams.getTrustAnchors().size());
                           var105.<init>(var10003, var10004, var10005);
                           var10000.addError(var108);
                           break label505;
                        } catch (CertPathReviewerException var51) {
                           var99 = var51;
                           var100 = false;
                        }
                     }
                  } else {
                     label512: {
                        TrustAnchor var113;
                        try {
                           var113 = (TrustAnchor)var70.iterator().next();
                        } catch (CertPathReviewerException var60) {
                           var99 = var60;
                           var100 = false;
                           break label512;
                        }

                        var1 = var113;

                        try {
                           var114 = var113.getTrustedCert();
                        } catch (CertPathReviewerException var59) {
                           var99 = var59;
                           var100 = false;
                           break label512;
                        }

                        if (var114 != null) {
                           try {
                              var116 = var1.getTrustedCert().getPublicKey();
                           } catch (CertPathReviewerException var58) {
                              var99 = var58;
                              var100 = false;
                              break label512;
                           }
                        } else {
                           try {
                              var116 = var1.getCAPublicKey();
                           } catch (CertPathReviewerException var57) {
                              var99 = var57;
                              var100 = false;
                              break label512;
                           }
                        }

                        PublicKey var71 = var116;

                        try {
                           var68.verify(var71);
                           break label505;
                        } catch (SignatureException var55) {
                           try {
                              this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.trustButInvalidCert"));
                              break label505;
                           } catch (CertPathReviewerException var46) {
                              var99 = var46;
                              var100 = false;
                           }
                        } catch (Exception var56) {
                           break label505;
                        }
                     }
                  }
               }
            }
         }

         this.addError(var99.getErrorMessage());
      }

      X500Principal var72;
      Object[] var107;
      if (var1 != null) {
         label434: {
            X500Principal var118;
            if ((var68 = var1.getTrustedCert()) != null) {
               label426: {
                  try {
                     var118 = CertPathValidatorUtilities.getSubjectPrincipal(var68);
                  } catch (IllegalArgumentException var43) {
                     var100 = false;
                     break label426;
                  }

                  var2 = var118;
                  var72 = var2;
                  break label434;
               }
            } else {
               label513: {
                  try {
                     var118 = new X500Principal;
                  } catch (IllegalArgumentException var45) {
                     var100 = false;
                     break label513;
                  }

                  var72 = var118;

                  try {
                     var118.<init>(var1.getCAName());
                     break label434;
                  } catch (IllegalArgumentException var44) {
                     var100 = false;
                  }
               }
            }

            Object[] var77;
            var107 = var77 = new Object[1];
            UntrustedInput var5;
            var5 = new UntrustedInput.<init>(var1.getCAName());
            var107[0] = var5;
            this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.trustDNInvalid", var77));
            var72 = var2;
         }

         boolean[] var66;
         if (var68 != null && (var66 = var68.getKeyUsage()) != null && !var66[5]) {
            ErrorBundle var67;
            var67 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.trustKeyUsage");
            this.addNotification(var67);
         }
      } else {
         var72 = var2;
      }

      PublicKey var69 = null;
      var68 = null;
      AlgorithmIdentifier var119;
      if (var1 != null) {
         label535: {
            if ((var68 = var1.getTrustedCert()) != null) {
               var69 = var68.getPublicKey();
            } else {
               var69 = var1.getCAPublicKey();
            }

            label515: {
               try {
                  var119 = CertPathValidatorUtilities.getAlgorithmIdentifier(var69);
                  var119.getObjectId();
               } catch (CertPathValidatorException var42) {
                  var100 = false;
                  break label515;
               }

               try {
                  var119.getParameters();
                  break label535;
               } catch (CertPathValidatorException var41) {
                  var100 = false;
               }
            }

            ErrorBundle var73;
            var73 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.trustPubKeyError");
            this.addError(var73);
         }
      }

      X509Certificate var7;
      for(int var75 = this.certs.size() - 1; var75 >= 0; var68 = var7) {
         int var6 = this.n - var75;
         var7 = (X509Certificate)this.certs.get(var75);
         Object[] var84;
         if (var69 != null) {
            try {
               var7.verify(var69, "INFOSEC");
            } catch (GeneralSecurityException var13) {
               var107 = var84 = new Object[3];
               var84[0] = var13.getMessage();
               var84[1] = var13;
               var107[2] = var13.getClass().getName();
               this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.signatureNotVerified", var84), var75);
            }
         } else if (CertPathValidatorUtilities.isSelfIssued(var7)) {
            label269: {
               GeneralSecurityException var126;
               label520: {
                  try {
                     var10000 = this;
                     var7.verify(var7.getPublicKey(), "INFOSEC");
                     var108 = new ErrorBundle;
                  } catch (GeneralSecurityException var17) {
                     var126 = var17;
                     var100 = false;
                     break label520;
                  }

                  var105 = var108;

                  try {
                     var105.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.rootKeyIsValidButNotATrustAnchor");
                     var10000.addError(var108, var75);
                     break label269;
                  } catch (GeneralSecurityException var16) {
                     var126 = var16;
                     var100 = false;
                  }
               }

               GeneralSecurityException var79 = var126;
               var107 = var84 = new Object[3];
               var84[0] = var79.getMessage();
               var84[1] = var79;
               var107[2] = var79.getClass().getName();
               this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.signatureNotVerified", var84), var75);
            }
         } else {
            ErrorBundle var8;
            var8 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.NoIssuerPublicKey");
            byte[] var9;
            if ((var9 = var7.getExtensionValue(X509Extensions.AuthorityKeyIdentifier.getId())) != null) {
               label521: {
                  AuthorityKeyIdentifier var120;
                  try {
                     var120 = AuthorityKeyIdentifier.getInstance(X509ExtensionUtil.fromExtensionValue(var9));
                  } catch (IOException var24) {
                     var100 = false;
                     break label521;
                  }

                  AuthorityKeyIdentifier var82 = var120;

                  GeneralNames var121;
                  try {
                     var121 = var120.getAuthorityCertIssuer();
                  } catch (IOException var23) {
                     var100 = false;
                     break label521;
                  }

                  GeneralNames var10 = var121;
                  if (var121 != null) {
                     label531: {
                        GeneralName var122;
                        try {
                           var120 = var82;
                           var122 = var10.getNames()[0];
                        } catch (IOException var22) {
                           var100 = false;
                           break label531;
                        }

                        GeneralName var83 = var122;

                        BigInteger var123;
                        try {
                           var123 = var120.getAuthorityCertSerialNumber();
                        } catch (IOException var21) {
                           var100 = false;
                           break label531;
                        }

                        BigInteger var86 = var123;
                        if (var123 != null) {
                           label532: {
                              ErrorBundle var124;
                              Object[] var125;
                              try {
                                 var124 = var8;
                                 var125 = new Object[7];
                              } catch (IOException var20) {
                                 var100 = false;
                                 break label532;
                              }

                              Object[] var106 = var125;
                              var107 = var125;
                              Object[] var111 = var125;
                              var10005 = var125;
                              var10006 = var125;
                              var10007 = var125;
                              Object[] var117 = var125;
                              byte var10009 = 0;

                              try {
                                 var117[var10009] = new LocaleString("cn.com.infosec.x509.CertPathReviewerMessages", "missingIssuer");
                                 var10007[1] = " \"";
                                 var10006[2] = var83;
                                 var10005[3] = "\" ";
                              } catch (IOException var19) {
                                 var100 = false;
                                 break label532;
                              }

                              byte var112 = 4;

                              try {
                                 var111[var112] = new LocaleString("cn.com.infosec.x509.CertPathReviewerMessages", "missingSerial");
                                 var107[5] = " ";
                                 var106[6] = var86;
                                 var124.setExtraArguments(var125);
                              } catch (IOException var18) {
                                 var100 = false;
                              }
                           }
                        }
                     }
                  }
               }
            }

            this.addError(var8, var75);
         }

         Object[] var80;
         TrustedInput var87;
         try {
            var7.checkValidity(this.validDate);
         } catch (CertificateNotYetValidException var14) {
            var107 = var80 = new Object[1];
            var87 = new TrustedInput.<init>(var7.getNotBefore());
            var107[0] = var87;
            this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.certificateNotYetValid", var80), var75);
         } catch (CertificateExpiredException var15) {
            var107 = var80 = new Object[1];
            var87 = new TrustedInput.<init>(var7.getNotAfter());
            var107[0] = var87;
            this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.certificateExpired", var80), var75);
         }

         if (this.pkixParams.isRevocationEnabled()) {
            label533: {
               var114 = var7;
               CRLDistPoint var81 = null;

               DERObject var127;
               label357: {
                  CRLDistPoint var128;
                  label356: {
                     label522: {
                        try {
                           var127 = CertPathValidatorUtilities.getExtensionValue(var114, CRL_DIST_POINTS);
                        } catch (AnnotatedException var31) {
                           var100 = false;
                           break label522;
                        }

                        DERObject var90 = var127;
                        if (var127 == null) {
                           break label357;
                        }

                        try {
                           var128 = CRLDistPoint.getInstance(var90);
                           break label356;
                        } catch (AnnotatedException var30) {
                           var100 = false;
                        }
                     }

                     ErrorBundle var93;
                     var93 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlDistPtExtError");
                     this.addError(var93, var75);
                     break label357;
                  }

                  var81 = var128;
               }

               var114 = var7;
               AuthorityInformationAccess var96 = null;

               label344: {
                  AuthorityInformationAccess var129;
                  label343: {
                     label523: {
                        try {
                           var127 = CertPathValidatorUtilities.getExtensionValue(var114, AUTH_INFO_ACCESS);
                        } catch (AnnotatedException var29) {
                           var100 = false;
                           break label523;
                        }

                        DERObject var88 = var127;
                        if (var127 == null) {
                           break label344;
                        }

                        try {
                           var129 = AuthorityInformationAccess.getInstance(var88);
                           break label343;
                        } catch (AnnotatedException var28) {
                           var100 = false;
                        }
                     }

                     ErrorBundle var89;
                     var89 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlAuthInfoAccError");
                     this.addError(var89, var75);
                     break label344;
                  }

                  var96 = var129;
               }

               Vector var85;
               Vector var130 = var85 = this.getCRLDistUrls(var81);
               Vector var98 = this.getOCSPUrls(var96);
               Iterator var91 = var130.iterator();

               UntrustedUrlInput var12;
               while(var91.hasNext()) {
                  Object[] var11;
                  var107 = var11 = new Object[1];
                  var12 = new UntrustedUrlInput.<init>(var91.next());
                  var107[0] = var12;
                  this.addNotification(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlDistPoint", var11), var75);
               }

               Iterator var92 = var98.iterator();

               while(var92.hasNext()) {
                  Object[] var94;
                  var107 = var94 = new Object[1];
                  var12 = new UntrustedUrlInput.<init>(var92.next());
                  var107[0] = var12;
                  this.addNotification(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.ocspLocation", var94), var75);
               }

               label524: {
                  PKIXParameters var109;
                  try {
                     var10000 = this;
                     var10001 = this;
                     var109 = this.pkixParams;
                  } catch (CertPathReviewerException var27) {
                     var99 = var27;
                     var100 = false;
                     break label524;
                  }

                  PKIXParameters var97 = var109;

                  Date var131;
                  try {
                     var131 = var10001.validDate;
                  } catch (CertPathReviewerException var26) {
                     var99 = var26;
                     var100 = false;
                     break label524;
                  }

                  Date var95 = var131;

                  try {
                     var10000.checkRevocation(var97, var7, var95, var68, var69, var85, var98, var75);
                     break label533;
                  } catch (CertPathReviewerException var25) {
                     var99 = var25;
                     var100 = false;
                  }
               }

               this.addError(var99.getErrorMessage(), var75);
            }
         }

         if (var72 != null && !var7.getIssuerX500Principal().equals(var72)) {
            var107 = var3 = new Object[2];
            var3[0] = var72.getName();
            var107[1] = var7.getIssuerX500Principal().getName();
            this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.certWrongIssuer", var3), var75);
         }

         ErrorBundle var74;
         if (var6 != this.n) {
            if (var7 != null && var7.getVersion() == 1) {
               var74 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.noCACert");
               this.addError(var74, var75);
            }

            label386: {
               label385: {
                  BasicConstraints var132;
                  try {
                     var132 = BasicConstraints.getInstance(CertPathValidatorUtilities.getExtensionValue(var7, CertPathValidatorUtilities.BASIC_CONSTRAINTS));
                  } catch (AnnotatedException var37) {
                     var100 = false;
                     break label385;
                  }

                  BasicConstraints var76 = var132;
                  if (var132 != null) {
                     label525: {
                        try {
                           var110 = var76.isCA();
                        } catch (AnnotatedException var34) {
                           var100 = false;
                           break label525;
                        }

                        if (var110) {
                           break label386;
                        }

                        try {
                           var10000 = this;
                           var108 = new ErrorBundle;
                        } catch (AnnotatedException var33) {
                           var100 = false;
                           break label525;
                        }

                        var105 = var108;

                        try {
                           var105.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.noCACert");
                           var10000.addError(var108, var75);
                           break label386;
                        } catch (AnnotatedException var32) {
                           var100 = false;
                        }
                     }
                  } else {
                     label526: {
                        try {
                           var10000 = this;
                           var108 = new ErrorBundle;
                        } catch (AnnotatedException var36) {
                           var100 = false;
                           break label526;
                        }

                        var105 = var108;

                        try {
                           var105.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.noBasicConstraints");
                           var10000.addError(var108, var75);
                           break label386;
                        } catch (AnnotatedException var35) {
                           var100 = false;
                        }
                     }
                  }
               }

               var74 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.errorProcesingBC");
               this.addError(var74, var75);
            }

            boolean[] var78;
            if ((var78 = var7.getKeyUsage()) != null && !var78[5]) {
               var74 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.noCertSign");
               this.addError(var74, var75);
            }
         }

         var10000 = this;
         var72 = var7.getSubjectX500Principal();

         label404: {
            label527: {
               try {
                  var116 = CertPathValidatorUtilities.getNextWorkingKey(var10000.certs, var75);
               } catch (CertPathValidatorException var40) {
                  var100 = false;
                  break label527;
               }

               var69 = var116;

               try {
                  var119 = CertPathValidatorUtilities.getAlgorithmIdentifier(var116);
                  var119.getObjectId();
               } catch (CertPathValidatorException var39) {
                  var100 = false;
                  break label527;
               }

               try {
                  var119.getParameters();
                  break label404;
               } catch (CertPathValidatorException var38) {
                  var100 = false;
               }
            }

            var74 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.pubKeyError");
            this.addError(var74, var75);
         }

         --var75;
      }

      this.trustAnchor = var1;
      this.subjectPublicKey = var69;
   }

   private void checkPolicy() {
      // $FF: Couldn't be decompiled
   }

   private void checkCriticalExtensions() {
      // $FF: Couldn't be decompiled
   }

   private boolean processQcStatements(X509Certificate cert, int index) {
      X509Certificate var10000 = cert;
      boolean cert1 = false;

      label202: {
         boolean var10001;
         ASN1Sequence var42;
         try {
            var42 = (ASN1Sequence)CertPathValidatorUtilities.getExtensionValue(var10000, QC_STATEMENT);
         } catch (AnnotatedException var37) {
            var10001 = false;
            break label202;
         }

         ASN1Sequence var3 = var42;
         int var4 = 0;

         while(true) {
            int var43;
            int var46;
            try {
               var43 = var4;
               var46 = var3.size();
            } catch (AnnotatedException var36) {
               var10001 = false;
               break;
            }

            if (var43 >= var46) {
               return cert1 ^ true;
            }

            QCStatement var44;
            try {
               var44 = QCStatement.getInstance(var3.getObjectAt(var4));
            } catch (AnnotatedException var35) {
               var10001 = false;
               break;
            }

            QCStatement var5 = var44;

            boolean var45;
            try {
               var45 = ETSIQCObjectIdentifiers.id_etsi_qcs_QcCompliance.equals(var5.getStatementId());
            } catch (AnnotatedException var34) {
               var10001 = false;
               break;
            }

            ErrorBundle var10002;
            PKIXCertPathReviewer var47;
            ErrorBundle var49;
            if (var45) {
               try {
                  var47 = this;
                  var49 = new ErrorBundle;
               } catch (AnnotatedException var33) {
                  var10001 = false;
                  break;
               }

               var10002 = var49;

               try {
                  var10002.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.QcEuCompliance");
                  var47.addNotification(var49, index);
               } catch (AnnotatedException var32) {
                  var10001 = false;
                  break;
               }
            } else {
               try {
                  var45 = RFC3739QCObjectIdentifiers.id_qcs_pkixQCSyntax_v1.equals(var5.getStatementId());
               } catch (AnnotatedException var31) {
                  var10001 = false;
                  break;
               }

               if (!var45) {
                  try {
                     var45 = ETSIQCObjectIdentifiers.id_etsi_qcs_QcSSCD.equals(var5.getStatementId());
                  } catch (AnnotatedException var30) {
                     var10001 = false;
                     break;
                  }

                  if (var45) {
                     try {
                        var47 = this;
                        var49 = new ErrorBundle;
                     } catch (AnnotatedException var29) {
                        var10001 = false;
                        break;
                     }

                     var10002 = var49;

                     try {
                        var10002.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.QcSSCD");
                        var47.addNotification(var49, index);
                     } catch (AnnotatedException var28) {
                        var10001 = false;
                        break;
                     }
                  } else {
                     try {
                        var45 = ETSIQCObjectIdentifiers.id_etsi_qcs_LimiteValue.equals(var5.getStatementId());
                     } catch (AnnotatedException var27) {
                        var10001 = false;
                        break;
                     }

                     Object[] var10006;
                     if (var45) {
                        MonetaryValue var51;
                        try {
                           var51 = MonetaryValue.getInstance(var5.getStatementInfo());
                        } catch (AnnotatedException var26) {
                           var10001 = false;
                           break;
                        }

                        MonetaryValue var58 = var51;
                        MonetaryValue var41;
                        MonetaryValue var48 = var41 = var51;

                        try {
                           var48.getCurrency();
                        } catch (AnnotatedException var25) {
                           var10001 = false;
                           break;
                        }

                        double var60;
                        try {
                           var60 = var58.getAmount().doubleValue();
                        } catch (AnnotatedException var24) {
                           var10001 = false;
                           break;
                        }

                        double var50 = 10.0;

                        try {
                           var50 = Math.pow(var50, var41.getExponent().doubleValue());
                        } catch (AnnotatedException var23) {
                           var10001 = false;
                           break;
                        }

                        double var6 = var60 * var50;

                        try {
                           var45 = var51.getCurrency().isAlphabetic();
                        } catch (AnnotatedException var22) {
                           var10001 = false;
                           break;
                        }

                        ErrorBundle var8;
                        Object[] var10003;
                        Object[] var10004;
                        Object[] var10005;
                        byte var10007;
                        String var53;
                        ErrorBundle var54;
                        byte var59;
                        String var63;
                        if (var45) {
                           try {
                              var54 = new ErrorBundle;
                           } catch (AnnotatedException var21) {
                              var10001 = false;
                              break;
                           }

                           var8 = var54;
                           var63 = "cn.com.infosec.x509.CertPathReviewerMessages";
                           var53 = "CertPathReviewer.QcLimitValueAlpha";

                           try {
                              var10003 = new Object[3];
                           } catch (AnnotatedException var20) {
                              var10001 = false;
                              break;
                           }

                           var10004 = var10003;
                           var10005 = var10003;
                           var10006 = var10003;
                           var10007 = 0;

                           try {
                              var10006[var10007] = var41.getCurrency().getAlphabetic();
                           } catch (AnnotatedException var19) {
                              var10001 = false;
                              break;
                           }

                           var59 = 1;

                           try {
                              var10005[var59] = new TrustedInput(new Double(var6));
                              var10004[2] = var41;
                              var54.<init>(var63, var53, var10003);
                           } catch (AnnotatedException var18) {
                              var10001 = false;
                              break;
                           }
                        } else {
                           try {
                              var54 = new ErrorBundle;
                           } catch (AnnotatedException var17) {
                              var10001 = false;
                              break;
                           }

                           var8 = var54;
                           var63 = "cn.com.infosec.x509.CertPathReviewerMessages";
                           var53 = "CertPathReviewer.QcLimitValueNum";

                           try {
                              var10003 = new Object[3];
                           } catch (AnnotatedException var16) {
                              var10001 = false;
                              break;
                           }

                           var10004 = var10003;
                           var10005 = var10003;
                           var10006 = var10003;
                           var10007 = 0;

                           try {
                              var10006[var10007] = new Integer(var41.getCurrency().getNumeric());
                           } catch (AnnotatedException var15) {
                              var10001 = false;
                              break;
                           }

                           var59 = 1;

                           try {
                              var10005[var59] = new TrustedInput(new Double(var6));
                              var10004[2] = var41;
                              var54.<init>(var63, var53, var10003);
                           } catch (AnnotatedException var14) {
                              var10001 = false;
                              break;
                           }
                        }

                        try {
                           this.addNotification(var8, index);
                        } catch (AnnotatedException var13) {
                           var10001 = false;
                           break;
                        }
                     } else {
                        try {
                           var47 = this;
                           var49 = new ErrorBundle;
                        } catch (AnnotatedException var12) {
                           var10001 = false;
                           break;
                        }

                        ErrorBundle var52 = var49;
                        int var55 = index;
                        String var56 = "cn.com.infosec.x509.CertPathReviewerMessages";
                        String var57 = "CertPathReviewer.QcUnknownStatement";

                        try {
                           var10006 = new Object[2];
                        } catch (AnnotatedException var11) {
                           var10001 = false;
                           break;
                        }

                        Object[] var61 = var10006;
                        Object[] var10008 = var10006;
                        QCStatement var10009 = var5;
                        byte cert2 = 0;

                        try {
                           var10008[cert2] = var10009.getStatementId();
                        } catch (AnnotatedException var10) {
                           var10001 = false;
                           break;
                        }

                        byte var62 = 1;

                        try {
                           var61[var62] = new UntrustedInput(var5);
                           var52.<init>(var56, var57, var10006);
                           var47.addNotification(var49, var55);
                        } catch (AnnotatedException var9) {
                           var10001 = false;
                           break;
                        }

                        cert1 = true;
                     }
                  }
               }
            }

            ++var4;
         }
      }

      ErrorBundle var38;
      var38 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.QcStatementExtError");
      this.addError(var38, index);
      return false;
   }

   private String IPtoString(byte[] ip) {
      String var10000;
      String var5;
      try {
         var10000 = InetAddress.getByAddress(ip).getHostAddress();
      } catch (Exception var3) {
         StringBuffer var4;
         var4 = new StringBuffer.<init>();

         for(int var2 = 0; var2 != ip.length; ++var2) {
            var4.append(Integer.toHexString(ip[var2] & 255));
            var4.append(' ');
         }

         var5 = var4.toString();
         return var5;
      }

      var5 = var10000;
      return var5;
   }

   private X509CRL getCRL(String location) {
      X509CRL var12 = null;

      Exception var10000;
      label67: {
         URL var16;
         boolean var10001;
         try {
            var16 = new URL;
         } catch (Exception var11) {
            var10000 = var11;
            var10001 = false;
            break label67;
         }

         URL var2;
         URL var18 = var2 = var16;

         boolean var17;
         try {
            var18.<init>(location);
            var17 = var16.getProtocol().equals("http");
         } catch (Exception var10) {
            var10000 = var10;
            var10001 = false;
            break label67;
         }

         if (!var17) {
            try {
               var17 = var2.getProtocol().equals("https");
            } catch (Exception var9) {
               var10000 = var9;
               var10001 = false;
               break label67;
            }

            if (!var17) {
               return var12;
            }
         }

         HttpURLConnection var19;
         try {
            var19 = (HttpURLConnection)var2.openConnection();
         } catch (Exception var8) {
            var10000 = var8;
            var10001 = false;
            break label67;
         }

         HttpURLConnection var20 = var19;
         HttpURLConnection var10002 = var19;
         HttpURLConnection var10003 = var19;
         HttpURLConnection var13;
         HttpURLConnection var10004 = var13 = var19;

         int var21;
         try {
            var10004.setUseCaches(false);
            var10003.setConnectTimeout(2000);
            var10002.setDoInput(true);
            var20.connect();
            var21 = var19.getResponseCode();
         } catch (Exception var7) {
            var10000 = var7;
            var10001 = false;
            break label67;
         }

         if (var21 != 200) {
            try {
               throw new Exception(var13.getResponseMessage());
            } catch (Exception var5) {
               var10000 = var5;
               var10001 = false;
            }
         } else {
            X509CRL var22;
            try {
               var22 = (X509CRL)CertificateFactory.getInstance("X.509", "INFOSEC").generateCRL(var13.getInputStream());
            } catch (Exception var6) {
               var10000 = var6;
               var10001 = false;
               break label67;
            }

            var12 = var22;
            return var12;
         }
      }

      Exception var14 = var10000;
      ErrorBundle var15;
      ErrorBundle var24 = var15 = new ErrorBundle;
      Object[] var3;
      Object[] var23 = var3 = new Object[4];
      UntrustedInput var4;
      var4 = new UntrustedInput.<init>(location);
      var3[0] = var4;
      var3[1] = var14.getMessage();
      var3[2] = var14;
      var23[3] = var14.getClass().getName();
      var24.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.loadCrlDistPointError", var3);
      throw new CertPathReviewerException(var15);
   }

   private Collection getTrustAnchors(X509Certificate cert, Set trustanchors) {
      ArrayList var6;
      var6 = new ArrayList.<init>();
      Iterator trustanchors1 = trustanchors.iterator();
      X509CertSelector var3;
      X509CertSelector var10000 = var3 = new X509CertSelector;
      X509Certificate var10001 = cert;
      var3.<init>();

      try {
         var10000.setSubject(CertPathValidatorUtilities.getEncodedIssuerPrincipal(var10001).getEncoded());
      } catch (IOException var5) {
         ErrorBundle var7;
         var7 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.trustAnchorIssuerError");
         throw new CertPathReviewerException(var7);
      }

      while(trustanchors1.hasNext()) {
         TrustAnchor var4;
         if ((var4 = (TrustAnchor)trustanchors1.next()).getTrustedCert() != null) {
            if (var3.match(var4.getTrustedCert())) {
               var6.add(var4);
            }
         } else if (var4.getCAName() != null && var4.getCAPublicKey() != null && CertPathValidatorUtilities.getEncodedIssuerPrincipal(cert).equals(new X500Principal(var4.getCAName()))) {
            var6.add(var4);
         }
      }

      return var6;
   }

   public void init(CertPath certPath, PKIXParameters params) {
      if (!this.initialized) {
         this.initialized = true;
         if (certPath != null) {
            this.certPath = certPath;
            List certPath1;
            this.certs = certPath1 = certPath.getCertificates();
            this.n = certPath1.size();
            if (!this.certs.isEmpty()) {
               PKIXCertPathReviewer var10000 = this;
               PKIXCertPathReviewer var10001 = this;
               PKIXCertPathReviewer var10002 = this;
               PKIXCertPathReviewer var10003 = this;
               PKIXCertPathReviewer var10004 = this;
               PKIXCertPathReviewer var10005 = this;
               PKIXParameters var4;
               this.pkixParams = var4 = (PKIXParameters)params.clone();
               var10005.validDate = CertPathValidatorUtilities.getValidDate(var4);
               var10004.notifications = null;
               var10003.errors = null;
               var10002.trustAnchor = null;
               var10001.subjectPublicKey = null;
               var10000.policyTree = null;
            } else {
               ErrorBundle var3;
               var3 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.emptyCertPath");
               throw new CertPathReviewerException(var3);
            }
         } else {
            throw new NullPointerException("certPath was null");
         }
      } else {
         throw new IllegalStateException("object is already initialized!");
      }
   }

   public CertPath getCertPath() {
      return this.certPath;
   }

   public int getCertPathSize() {
      return this.n;
   }

   public List[] getErrors() {
      this.doChecks();
      return this.errors;
   }

   public List getErrors(int index) {
      this.doChecks();
      return this.errors[index + 1];
   }

   public List[] getNotifications() {
      this.doChecks();
      return this.notifications;
   }

   public List getNotifications(int index) {
      this.doChecks();
      return this.notifications[index + 1];
   }

   public PolicyNode getPolicyTree() {
      this.doChecks();
      return this.policyTree;
   }

   public PublicKey getSubjectPublicKey() {
      this.doChecks();
      return this.subjectPublicKey;
   }

   public TrustAnchor getTrustAnchor() {
      this.doChecks();
      return this.trustAnchor;
   }

   public boolean isValidCertPath() {
      this.doChecks();
      boolean var1 = true;

      List[] var3;
      for(int var2 = 0; var2 < (var3 = this.errors).length; ++var2) {
         if (!var3[var2].isEmpty()) {
            var1 = false;
            break;
         }
      }

      return var1;
   }

   protected void addNotification(ErrorBundle msg) {
      this.notifications[0].add(msg);
   }

   protected void addNotification(ErrorBundle msg, int index) {
      if (index >= -1 && index < this.n) {
         this.notifications[index + 1].add(msg);
      } else {
         throw new IndexOutOfBoundsException();
      }
   }

   protected void addError(ErrorBundle msg) {
      this.errors[0].add(msg);
   }

   protected void addError(ErrorBundle msg, int index) {
      if (index >= -1 && index < this.n) {
         this.errors[index + 1].add(msg);
      } else {
         throw new IndexOutOfBoundsException();
      }
   }

   protected void doChecks() {
      if (!this.initialized) {
         throw new IllegalStateException("Object not initialized. Call init() first.");
      } else {
         if (this.notifications == null) {
            int var10001 = this.n;
            this.notifications = new List[var10001 + 1];
            this.errors = new List[var10001 + 1];

            List[] var2;
            for(int var1 = 0; var1 < (var2 = this.notifications).length; ++var1) {
               ArrayList var3;
               var3 = new ArrayList.<init>();
               var2[var1] = var3;
               List[] var10000 = this.errors;
               var3 = new ArrayList.<init>();
               var10000[var1] = var3;
            }

            this.checkSignatures();
            this.checkNameConstraints();
            this.checkPathLength();
            this.checkPolicy();
            this.checkCriticalExtensions();
         }

      }
   }

   protected void checkRevocation(PKIXParameters paramsPKIX, X509Certificate cert, Date validDate, X509Certificate sign, PublicKey workingPublicKey, Vector crlDistPointUrls, Vector ocspUrls, int index) {
      this.checkCRLs(paramsPKIX, cert, validDate, sign, workingPublicKey, crlDistPointUrls, index);
   }

   protected void checkCRLs(PKIXParameters paramsPKIX, X509Certificate cert, Date validDate, X509Certificate sign, PublicKey workingPublicKey, Vector crlDistPointUrls, int index) {
      X509CRLStoreSelector var8;
      X509CRLStoreSelector var10000 = var8 = new X509CRLStoreSelector;
      PKIXParameters var10001 = paramsPKIX;
      X509CRLStoreSelector var10004 = var8;
      X509Certificate var10005 = cert;
      var8.<init>();

      ErrorBundle paramsPKIX1;
      try {
         var10004.addIssuerName(CertPathValidatorUtilities.getEncodedIssuerPrincipal(var10005).getEncoded());
      } catch (IOException var22) {
         paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlIssuerException");
         throw new CertPathReviewerException(paramsPKIX1, var22);
      }

      var8.setCertificateChecking(cert);

      Iterator var9;
      int var10002;
      ErrorBundle var10003;
      Object[] var10006;
      Object[] var10007;
      Object[] var10008;
      Object[] var10009;
      byte var10010;
      Object[] var83;
      boolean var92;
      boolean var93;
      Iterator var96;
      Object[] var97;
      String var100;
      PKIXCertPathReviewer var102;
      String var103;
      ErrorBundle var104;
      byte var110;
      byte var112;
      label484: {
         AnnotatedException var90;
         label488: {
            Collection var91;
            Iterator var94;
            try {
               var91 = CertPathValidatorUtilities.findCRLs(var10000, var10001.getCertStores());
               var94 = var91.iterator();
            } catch (AnnotatedException var57) {
               var90 = var57;
               var92 = false;
               break label488;
            }

            var9 = var94;

            try {
               var93 = var91.isEmpty();
            } catch (AnnotatedException var56) {
               var90 = var56;
               var92 = false;
               break label488;
            }

            if (!var93) {
               break label484;
            }

            try {
               var10000 = new X509CRLStoreSelector;
            } catch (AnnotatedException var55) {
               var90 = var55;
               var92 = false;
               break label488;
            }

            X509CRLStoreSelector var95 = var10000;

            try {
               var95.<init>();
               var96 = CertPathValidatorUtilities.findCRLs(var10000, paramsPKIX.getCertStores()).iterator();
            } catch (AnnotatedException var54) {
               var90 = var54;
               var92 = false;
               break label488;
            }

            Iterator var10 = var96;

            ArrayList var98;
            try {
               var98 = new ArrayList;
            } catch (AnnotatedException var53) {
               var90 = var53;
               var92 = false;
               break label488;
            }

            ArrayList var11 = var98;

            try {
               var98.<init>();
            } catch (AnnotatedException var52) {
               var90 = var52;
               var92 = false;
               break label488;
            }

            while(true) {
               try {
                  var93 = var10.hasNext();
               } catch (AnnotatedException var50) {
                  var90 = var50;
                  var92 = false;
                  break;
               }

               if (!var93) {
                  int var101;
                  try {
                     var102 = this;
                     var101 = var11.size();
                  } catch (AnnotatedException var49) {
                     var90 = var49;
                     var92 = false;
                     break;
                  }

                  int var84 = var101;

                  try {
                     var104 = new ErrorBundle;
                  } catch (AnnotatedException var48) {
                     var90 = var48;
                     var92 = false;
                     break;
                  }

                  var10003 = var104;
                  var10002 = index;
                  var100 = "cn.com.infosec.x509.CertPathReviewerMessages";
                  var103 = "CertPathReviewer.noCrlInCertstore";

                  try {
                     var10006 = new Object[3];
                  } catch (AnnotatedException var47) {
                     var90 = var47;
                     var92 = false;
                     break;
                  }

                  var10007 = var10006;
                  var10008 = var10006;
                  var10009 = var10006;
                  var10010 = 0;

                  try {
                     var10009[var10010] = new UntrustedInput(var8.getIssuers());
                  } catch (AnnotatedException var46) {
                     var90 = var46;
                     var92 = false;
                     break;
                  }

                  var112 = 1;

                  try {
                     var10008[var112] = new UntrustedInput(var11);
                  } catch (AnnotatedException var45) {
                     var90 = var45;
                     var92 = false;
                     break;
                  }

                  var110 = 2;

                  try {
                     var10007[var110] = new Integer(var84);
                     var10003.<init>(var100, var103, var10006);
                     var102.addNotification(var104, var10002);
                     break label484;
                  } catch (AnnotatedException var44) {
                     var90 = var44;
                     var92 = false;
                     break;
                  }
               }

               try {
                  var11.add(((X509CRL)var10.next()).getIssuerX500Principal());
               } catch (AnnotatedException var51) {
                  var90 = var51;
                  var92 = false;
                  break;
               }
            }
         }

         AnnotatedException var81 = var90;
         var97 = var83 = new Object[3];
         var83[0] = var81.getCause().getMessage();
         var83[1] = var81.getCause();
         var97[2] = var81.getCause().getClass().getName();
         this.addError(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlExtractionError", var83), index);
         var9 = (new ArrayList()).iterator();
      }

      boolean var82 = false;
      X509CRL var85 = null;

      while(var9.hasNext()) {
         if ((var85 = (X509CRL)var9.next()).getNextUpdate() == null || (new Date()).before(var85.getNextUpdate())) {
            var82 = true;
            var97 = var83 = new Object[2];
            TrustedInput var88;
            var88 = new TrustedInput.<init>(var85.getThisUpdate());
            var97[0] = var88;
            var88 = new TrustedInput.<init>(var85.getNextUpdate());
            var97[1] = var88;
            this.addNotification(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.localValidCRL", var83), index);
            break;
         }

         Object[] var87;
         var97 = var87 = new Object[2];
         TrustedInput var12;
         var12 = new TrustedInput.<init>(var85.getThisUpdate());
         var97[0] = var12;
         var12 = new TrustedInput.<init>(var85.getNextUpdate());
         var97[1] = var12;
         this.addNotification(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.localInvalidCRL", var87), index);
      }

      X509CRL var89;
      X509CRL var111;
      Date var114;
      label513: {
         if (!var82) {
            Iterator crlDistPointUrls1 = crlDistPointUrls.iterator();

            while(crlDistPointUrls1.hasNext()) {
               CertPathReviewerException var108;
               label494: {
                  String var107;
                  try {
                     var102 = this;
                     var107 = (String)crlDistPointUrls1.next();
                  } catch (CertPathReviewerException var43) {
                     var108 = var43;
                     var92 = false;
                     break label494;
                  }

                  String var86 = var107;

                  try {
                     var111 = var102.getCRL(var107);
                  } catch (CertPathReviewerException var42) {
                     var108 = var42;
                     var92 = false;
                     break label494;
                  }

                  var89 = var111;
                  if (var111 == null) {
                     continue;
                  }

                  try {
                     var93 = cert.getIssuerX500Principal().equals(var89.getIssuerX500Principal());
                  } catch (CertPathReviewerException var41) {
                     var108 = var41;
                     var92 = false;
                     break label494;
                  }

                  if (!var93) {
                     label495: {
                        try {
                           var102 = this;
                           var104 = new ErrorBundle;
                        } catch (CertPathReviewerException var27) {
                           var108 = var27;
                           var92 = false;
                           break label495;
                        }

                        var10003 = var104;
                        var10002 = index;
                        var100 = "cn.com.infosec.x509.CertPathReviewerMessages";
                        var103 = "CertPathReviewer.onlineCRLWrongCA";

                        try {
                           var10006 = new Object[3];
                        } catch (CertPathReviewerException var26) {
                           var108 = var26;
                           var92 = false;
                           break label495;
                        }

                        var10007 = var10006;
                        var10008 = var10006;
                        var10009 = var10006;
                        var10010 = 0;

                        try {
                           var10009[var10010] = new UntrustedInput(var89.getIssuerX500Principal().getName());
                        } catch (CertPathReviewerException var25) {
                           var108 = var25;
                           var92 = false;
                           break label495;
                        }

                        var112 = 1;

                        try {
                           var10008[var112] = new UntrustedInput(cert.getIssuerX500Principal().getName());
                        } catch (CertPathReviewerException var24) {
                           var108 = var24;
                           var92 = false;
                           break label495;
                        }

                        var110 = 2;

                        try {
                           var10007[var110] = new UntrustedUrlInput(var86);
                           var10003.<init>(var100, var103, var10006);
                           var102.addNotification(var104, var10002);
                           continue;
                        } catch (CertPathReviewerException var23) {
                           var108 = var23;
                           var92 = false;
                        }
                     }
                  } else {
                     label496: {
                        try {
                           var114 = var89.getNextUpdate();
                        } catch (CertPathReviewerException var40) {
                           var108 = var40;
                           var92 = false;
                           break label496;
                        }

                        if (var114 != null) {
                           try {
                              var114 = new Date;
                           } catch (CertPathReviewerException var39) {
                              var108 = var39;
                              var92 = false;
                              break label496;
                           }

                           Date var113 = var114;

                           try {
                              var113.<init>();
                              var93 = var114.before(var89.getNextUpdate());
                           } catch (CertPathReviewerException var38) {
                              var108 = var38;
                              var92 = false;
                              break label496;
                           }

                           if (!var93) {
                              try {
                                 var102 = this;
                                 var104 = new ErrorBundle;
                              } catch (CertPathReviewerException var32) {
                                 var108 = var32;
                                 var92 = false;
                                 break label496;
                              }

                              var10003 = var104;
                              var10002 = index;
                              var100 = "cn.com.infosec.x509.CertPathReviewerMessages";
                              var103 = "CertPathReviewer.onlineInvalidCRL";

                              try {
                                 var10006 = new Object[3];
                              } catch (CertPathReviewerException var31) {
                                 var108 = var31;
                                 var92 = false;
                                 break label496;
                              }

                              var10007 = var10006;
                              var10008 = var10006;
                              var10009 = var10006;
                              var10010 = 0;

                              try {
                                 var10009[var10010] = new TrustedInput(var89.getThisUpdate());
                              } catch (CertPathReviewerException var30) {
                                 var108 = var30;
                                 var92 = false;
                                 break label496;
                              }

                              var112 = 1;

                              try {
                                 var10008[var112] = new TrustedInput(var89.getNextUpdate());
                              } catch (CertPathReviewerException var29) {
                                 var108 = var29;
                                 var92 = false;
                                 break label496;
                              }

                              var110 = 2;

                              try {
                                 var10007[var110] = new UntrustedUrlInput(var86);
                                 var10003.<init>(var100, var103, var10006);
                                 var102.addNotification(var104, var10002);
                                 continue;
                              } catch (CertPathReviewerException var28) {
                                 var108 = var28;
                                 var92 = false;
                                 break label496;
                              }
                           }
                        }

                        var102 = this;
                        var82 = true;

                        try {
                           var104 = new ErrorBundle;
                        } catch (CertPathReviewerException var37) {
                           var108 = var37;
                           var92 = false;
                           break label496;
                        }

                        var10003 = var104;
                        var10002 = index;
                        var100 = "cn.com.infosec.x509.CertPathReviewerMessages";
                        var103 = "CertPathReviewer.onlineValidCRL";

                        try {
                           var10006 = new Object[3];
                        } catch (CertPathReviewerException var36) {
                           var108 = var36;
                           var92 = false;
                           break label496;
                        }

                        var10007 = var10006;
                        var10008 = var10006;
                        var10009 = var10006;
                        var10010 = 0;

                        try {
                           var10009[var10010] = new TrustedInput(var89.getThisUpdate());
                        } catch (CertPathReviewerException var35) {
                           var108 = var35;
                           var92 = false;
                           break label496;
                        }

                        var112 = 1;

                        try {
                           var10008[var112] = new TrustedInput(var89.getNextUpdate());
                        } catch (CertPathReviewerException var34) {
                           var108 = var34;
                           var92 = false;
                           break label496;
                        }

                        var110 = 2;

                        try {
                           var10007[var110] = new UntrustedUrlInput(var86);
                           var10003.<init>(var100, var103, var10006);
                           var102.addNotification(var104, var10002);
                           break label513;
                        } catch (CertPathReviewerException var33) {
                           var108 = var33;
                           var92 = false;
                        }
                     }
                  }
               }

               this.addNotification(var108.getErrorMessage(), index);
            }
         }

         var89 = var85;
      }

      ErrorBundle var58;
      if (var89 != null) {
         boolean[] sign1;
         if (sign != null && (sign1 = sign.getKeyUsage()) != null && (sign1.length < 7 || !sign1[6])) {
            var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.noCrlSigningPermited");
            throw new CertPathReviewerException(var58);
         }

         if (workingPublicKey == null) {
            var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlNoIssuerPublicKey");
            throw new CertPathReviewerException(var58);
         }

         X509Certificate var115;
         try {
            var111 = var89;
            var115 = cert;
            var89.verify(workingPublicKey, "INFOSEC");
         } catch (Exception var21) {
            paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlVerifyFailed");
            throw new CertPathReviewerException(paramsPKIX1, var21);
         }

         X509CRLEntry sign2;
         if ((sign2 = var111.getRevokedCertificate(var115.getSerialNumber())) != null) {
            String workingPublicKey1 = null;
            if (sign2.hasExtensions()) {
               DEREnumerated var119;
               try {
                  var119 = DEREnumerated.getInstance(CertPathValidatorUtilities.getExtensionValue(sign2, X509Extensions.ReasonCode.getId()));
               } catch (AnnotatedException var20) {
                  paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlReasonExtError");
                  throw new CertPathReviewerException(paramsPKIX1, var20);
               }

               DEREnumerated workingPublicKey2 = var119;
               if (var119 != null) {
                  workingPublicKey1 = CertPathValidatorUtilities.crlReasons[workingPublicKey2.getValue().intValue()];
               } else {
                  workingPublicKey1 = CertPathValidatorUtilities.crlReasons[7];
               }
            }

            var114 = validDate;
            LocaleString validDate1;
            validDate1 = new LocaleString.<init>("cn.com.infosec.x509.CertPathReviewerMessages", workingPublicKey1);
            if (!var114.before(sign2.getRevocationDate())) {
               ErrorBundle var120 = var58 = new ErrorBundle;
               Object[] paramsPKIX2;
               Object[] var116 = paramsPKIX2 = new Object[2];
               TrustedInput cert1;
               cert1 = new TrustedInput.<init>(sign2.getRevocationDate());
               var116[0] = cert1;
               var116[1] = validDate1;
               var120.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.certRevoked", paramsPKIX2);
               throw new CertPathReviewerException(var58);
            }

            Object[] workingPublicKey3;
            var97 = workingPublicKey3 = new Object[2];
            TrustedInput crlDistPointUrls2;
            crlDistPointUrls2 = new TrustedInput.<init>(sign2.getRevocationDate());
            var97[0] = crlDistPointUrls2;
            var97[1] = validDate1;
            this.addNotification(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.revokedAfterValidation", workingPublicKey3), index);
         } else {
            ErrorBundle validDate2;
            validDate2 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.notRevoked");
            this.addNotification(validDate2, index);
         }

         if (var89.getNextUpdate() != null && var89.getNextUpdate().before(new Date())) {
            var102 = this;
            Object[] var59;
            var97 = var59 = new Object[1];
            TrustedInput validDate3;
            validDate3 = new TrustedInput.<init>(var89.getNextUpdate());
            var97[0] = validDate3;
            var102.addNotification(new ErrorBundle("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlUpdateAvailable", var59), index);
         }

         DERObject var117;
         try {
            var111 = var89;
            var117 = CertPathValidatorUtilities.getExtensionValue(var89, CertPathValidatorUtilities.ISSUING_DISTRIBUTION_POINT);
         } catch (AnnotatedException var19) {
            var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.distrPtExtError");
            throw new CertPathReviewerException(var58);
         }

         DERObject var61 = var117;

         DERObject var121;
         try {
            var121 = CertPathValidatorUtilities.getExtensionValue(var111, CertPathValidatorUtilities.DELTA_CRL_INDICATOR);
         } catch (AnnotatedException var18) {
            var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.deltaCrlExtError");
            throw new CertPathReviewerException(var58);
         }

         DERObject validDate4 = var121;
         if (var121 != null) {
            X509CRLStoreSelector sign3;
            var10000 = sign3 = new X509CRLStoreSelector;
            var10001 = paramsPKIX;
            X509CRLStoreSelector var99 = sign3;
            X509CRL var105 = var89;
            X509CRLStoreSelector var106 = sign3;
            X509CRL var109 = var89;
            sign3.<init>();

            try {
               var106.addIssuerName(CertPathValidatorUtilities.getIssuerPrincipal(var109).getEncoded());
            } catch (IOException var17) {
               paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlIssuerException");
               throw new CertPathReviewerException(paramsPKIX1, var17);
            }

            sign3.setMinCRLNumber(((DERInteger)validDate4).getPositiveValue());

            try {
               var99.setMaxCRLNumber(((DERInteger)CertPathValidatorUtilities.getExtensionValue(var105, CertPathValidatorUtilities.CRL_NUMBER)).getPositiveValue().subtract(BigInteger.valueOf(1L)));
            } catch (AnnotatedException var16) {
               paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlNbrExtError");
               throw new CertPathReviewerException(paramsPKIX1, var16);
            }

            boolean paramsPKIX3 = false;

            try {
               var96 = CertPathValidatorUtilities.findCRLs(var10000, var10001.getCertStores()).iterator();
            } catch (AnnotatedException var15) {
               paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlExtractionError");
               throw new CertPathReviewerException(paramsPKIX1, var15);
            }

            Iterator validDate5 = var96;

            label305: {
               while(true) {
                  if (!validDate5.hasNext()) {
                     break label305;
                  }

                  X509CRL var118 = (X509CRL)validDate5.next();

                  try {
                     var117 = CertPathValidatorUtilities.getExtensionValue(var118, CertPathValidatorUtilities.ISSUING_DISTRIBUTION_POINT);
                  } catch (AnnotatedException var14) {
                     paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.distrPtExtError");
                     throw new CertPathReviewerException(paramsPKIX1, var14);
                  }

                  DERObject sign4 = var117;
                  if (var61 == null) {
                     if (sign4 == null) {
                        break;
                     }
                  } else if (var61.equals(sign4)) {
                     break;
                  }
               }

               paramsPKIX3 = true;
            }

            if (!paramsPKIX3) {
               var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.noBaseCRL");
               throw new CertPathReviewerException(var58);
            }
         }

         if (var61 != null) {
            X509Certificate var122 = cert;
            IssuingDistributionPoint var62 = IssuingDistributionPoint.getInstance(var61);

            BasicConstraints var123;
            try {
               var123 = BasicConstraints.getInstance(CertPathValidatorUtilities.getExtensionValue(var122, CertPathValidatorUtilities.BASIC_CONSTRAINTS));
            } catch (AnnotatedException var13) {
               paramsPKIX1 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlBCExtError");
               throw new CertPathReviewerException(paramsPKIX1, var13);
            }

            BasicConstraints paramsPKIX4 = var123;
            if (var62.onlyContainsUserCerts() && paramsPKIX4 != null && paramsPKIX4.isCA()) {
               var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlOnlyUserCert");
               throw new CertPathReviewerException(var58);
            }

            if (var62.onlyContainsCACerts() && (paramsPKIX4 == null || !paramsPKIX4.isCA())) {
               var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlOnlyCaCert");
               throw new CertPathReviewerException(var58);
            }

            if (var62.onlyContainsAttributeCerts()) {
               var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.crlOnlyAttrCert");
               throw new CertPathReviewerException(var58);
            }
         }
      }

      if (!var82) {
         var58 = new ErrorBundle.<init>("cn.com.infosec.x509.CertPathReviewerMessages", "CertPathReviewer.noValidCrlFound");
         throw new CertPathReviewerException(var58);
      }
   }

   protected Vector getCRLDistUrls(CRLDistPoint crlDistPoints) {
      Vector var5;
      var5 = new Vector.<init>();
      if (crlDistPoints != null) {
         DistributionPoint[] crlDistPoints1 = crlDistPoints.getDistributionPoints();

         for(int var2 = 0; var2 < crlDistPoints1.length; ++var2) {
            DistributionPointName var3;
            if ((var3 = crlDistPoints1[var2].getDistributionPoint()).getType() == 0) {
               GeneralName[] var7 = GeneralNames.getInstance(var3.getName()).getNames();

               for(int var4 = 0; var4 < var7.length; ++var4) {
                  if (var7[var4].getTagNo() == 6) {
                     var5.add(((DERIA5String)var7[var4].getName()).getString());
                  }
               }
            }
         }
      }

      return var5;
   }

   protected Vector getOCSPUrls(AuthorityInformationAccess authInfoAccess) {
      Vector var4;
      var4 = new Vector.<init>();
      if (authInfoAccess != null) {
         AccessDescription[] authInfoAccess1 = authInfoAccess.getAccessDescriptions();

         for(int var2 = 0; var2 < authInfoAccess1.length; ++var2) {
            GeneralName var3;
            if (authInfoAccess1[var2].getAccessMethod().equals(AccessDescription.id_ad_ocsp) && (var3 = authInfoAccess1[var2].getAccessLocation()).getTagNo() == 6) {
               var4.add(((DERIA5String)var3.getName()).getString());
            }
         }
      }

      return var4;
   }
}
